# doit cmd plugin: **auto**

Watch filesystem and re-execute on changes.

# Status

This is the *first* generation of `doit` `auto` command.

It is based on:

- Linux: pyinotify <https://pypi.org/project/pyinotify>
- MAC: macfsevents <https://pypi.python.org/pypi/MacFSEvents>`

Unfortunately both of this projects are not maintained anymore.
